import * as pipelines from 'aws-cdk-lib/pipelines';
import { IConstruct } from 'constructs';
import { ResourceContext, IResourceProvider, RepositoryConfig } from '../common';
/**
 * Represents a repository stack in the pipeline.
 */
export interface IRepositoryStack extends IConstruct {
    readonly pipelineInput: pipelines.IFileSetProducer;
    readonly pipelineEnvVars: {
        [key: string]: string;
    };
    readonly repositoryBranch: string;
}
/**
 * Provider for repository resources.
 */
export type RepositoryProvider = IResourceProvider;
/**
 * Base properties for repository provider.
 */
export interface BaseRepositoryProviderProps extends RepositoryConfig {
    readonly codeStarConnectionArn?: string;
    readonly codeGuruReviewer?: boolean;
}
/**
 * Basic implementation of repository provider.
 */
export declare class BasicRepositoryProvider implements RepositoryProvider {
    readonly config: BaseRepositoryProviderProps;
    constructor(config?: BaseRepositoryProviderProps);
    /**
     * Provides a repository stack based on the configuration.
     * @param context The resource context.
     * @returns The repository stack.
     */
    provide(context: ResourceContext): any;
}
