import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { IConstruct } from 'constructs';
import { ResourceContext, IResourceProvider } from '../common';
/**
 * Legacy VPC Type Definitions
 */
export type VpcType = 'NO_VPC' | 'VPC' | 'VPC_FROM_LOOK_UP';
/**
 * VPC Configuration for new VPC
 */
export interface IVpcConfigNewVpc {
    /**
     * CIDR block for the VPC. default is: 172.31.0.0/20
     */
    cidrBlock: string;
    /**
     * Subnets CIDR masks. default is: 24
     */
    subnetCidrMask: number;
    /**
     * Max AZs. default is: 2
     */
    maxAzs: number;
}
/**
 * VPC Configuration for VPC id lookup
 */
export interface IVpcConfigFromLookUp {
    /**
     * VPC id to lookup
     */
    vpcId: string;
}
/**
 * Interface representing VPC configuration
 */
export interface IVpcConfig {
    vpcType: VpcType;
    vpc?: IVpcConfigNewVpc;
    vpcFromLookUp?: IVpcConfigFromLookUp;
}
/**
 * VPC construct that provides the VPC and HTTP proxy settings
 */
export interface IVpcConstruct extends IConstruct {
    readonly vpc?: ec2.IVpc;
}
/**
 * Legacy VPC Provider that defines the VPC used by the CI/CD process
 */
export declare class VPCProvider implements IResourceProvider {
    readonly vpc: IVpcConfig;
    constructor(vpc?: IVpcConfig);
    /**
     * Provides the VPC resource
     * @param context The resource context
     * @returns The VPC stack
     */
    provide(context: ResourceContext): any;
}
