import * as cdk from 'aws-cdk-lib';
import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { Construct } from 'constructs';
import { IVpcConfig } from '../resource-providers';
/**
 * Properties for the VPCStack.
 */
export interface VPCStackProps extends cdk.StackProps {
    /**
     * The configuration for the VPC to be created or looked up.
     */
    readonly vpcConfig: IVpcConfig;
    /**
     * Whether to use a proxy for the VPC.
     * Default value is false.
     */
    readonly useProxy: boolean;
    /**
     * The name of the S3 bucket for VPC flow logs.
     */
    readonly flowLogsBucketName?: string;
}
/**
 * A stack that creates or looks up a VPC and configures its settings.
 */
export declare class VPCStack extends cdk.Stack {
    /**
     * The VPC created or looked up by this stack.
     */
    readonly vpc: ec2.IVpc | undefined;
    constructor(scope: Construct, id: string, props: VPCStackProps);
    /**
     * Launches a VPC with an isolated subnet and configures security groups and VPC endpoints.
     * @param props The properties for configuring the VPC.
     * @returns The created VPC.
     */
    private launchVPCIsolated;
    /**
     * Launches a VPC with a private subnet with egress and a public subnet.
     * @param props The properties for configuring the VPC.
     * @returns The created VPC.
     */
    private launchVPCWithEgress;
}
