import { aws_kms, IAspect } from 'aws-cdk-lib';
import { IConstruct } from 'constructs';
/**
 * Implements security controls across various AWS services.
 */
export declare class SecurityControls implements IAspect {
    private encryptionKey;
    private readonly stage;
    private readonly logRetentionInDays;
    private readonly complianceLogBucketName?;
    /**
     * Constructs a new instance of SecurityControls.
     *
     * @param kmsKey The KMS key to use for encryption.
     * @param stage The deployment stage (e.g., dev, prod).
     * @param logRetentionInDays The number of days to retain logs.
     * @param complianceLogBucketName The name of the S3 bucket for compliance logs.
     */
    constructor(kmsKey: aws_kms.Key, stage: string, logRetentionInDays: string, complianceLogBucketName?: string);
    /**
     * Visits an AWS CDK construct and applies security controls.
     *
     * @param node The construct to visit.
     */
    visit(node: IConstruct): void;
}
